==> owncloud-8.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/settings/l10n/lt_LT.js <==
OC.L10N.register(
    "settings",
    {
    "Sharing" : "Dalijimasis",
    "External Storage" : "Išorinės saugyklos",
    "Cron" : "Cron",
    "Log" : "Žurnalas",
    "Updates" : "Atnaujinimai",
    "Authentication error" : "Autentikacijos klaida",
    "Language changed" : "Kalba pakeista",
    "Invalid request" : "Klaidinga užklausa",
    "Admins can't remove themself from the admin group" : "Administratoriai negali pašalinti savęs iš administratorių grupės",
    "Unable to add user to group %s" : "Nepavyko pridėti vartotojo prie grupės %s",
    "Unable to remove user from group %s" : "Nepavyko ištrinti vartotojo iš grupės %s",
    "Couldn't update app." : "Nepavyko atnaujinti programos.",
    "Wrong password" : "Neteisingas slaptažodis",
    "No user supplied" : "Nepateiktas naudotojas",
    "Please provide an admin recovery password, otherwise all user data will be lost" : "Prašome įvesti administratoriaus atkūrimo slaptažodį, kitaip visi naudotojo suomenys bus prarasti",
    "Wrong admin recovery password. Please check the password and try again." : "Netinkamas administratoriau atkūrimo slaptažodis. Prašome pasitikrinti ir bandyti vėl.",
    "Unable to change password" : "Nepavyksta pakeisti slaptažodžio",
    "Enabled" : "Įjungta",
    "Saved" : "Išsaugoti",
    "Email sent" : "Laiškas išsiųstas",
    "Email saved" : "El. paštas išsaugotas",
    "All" : "Viskas",
    "Please wait...." : "Prašome palaukti...",
    "Error while disabling app" : "Klaida išjungiant programą",
    "Disable" : "Išjungti",
    "Enable" : "Įjungti",
    "Error while enabling app" : "Klaida įjungiant programą",
    "Updating...." : "Atnaujinama...",
    "Error while updating app" : "Įvyko klaida atnaujinant programą",
    "Updated" : "Atnaujinta",
    "Select a profile picture" : "Pažymėkite profilio paveikslėlį",
    "Very weak password" : "Labai silpnas slaptažodis",
    "Weak password" : "Silpnas slaptažodis",
    "So-so password" : "Neblogas slaptažodis",
    "Good password" : "Geras slaptažodis",
    "Strong password" : "Stiprus slaptažodis",
    "Delete" : "Ištrinti",
    "Groups" : "Grupės",
    "undo" : "anuliuoti",
    "never" : "niekada",
    "add group" : "pridėti grupę",
    "A valid username must be provided" : "Vartotojo vardas turi būti tinkamas",
    "Error creating user" : "Klaida kuriant vartotoją",
    "A valid password must be provided" : "Slaptažodis turi būti tinkamas",
    "__language_name__" : "Lietuvių",
    "SSL root certificates" : "SSL sertifikatas",
    "Fatal issues only" : "Tik kritinės problemos",
    "None" : "Nieko",
    "Login" : "Prisijungti",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "Trūksta PHP modulio „fileinfo“. Labai rekomenduojame įjungti šį modulį, kad gauti geriausius rezultatus nustatant mime-tipą.",
    "Allow apps to use the Share API" : "Leidžia programoms naudoti Share API",
    "Allow public uploads" : "Leisti viešus įkėlimus",
    "days" : "dienos",
    "Allow resharing" : "Leisti dalintis",
    "Execute one task with each page loaded" : "Įvykdyti vieną užduotį su kiekvieno puslapio įkėlimu",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php yra registruotas tinklapio suplanuotų užduočių paslaugose, kad iškviesti cron.php kas 15 minučių per http.",
    "Encryption" : "Šifravimas",
    "Authentication required" : "Reikalinga autentikacija",
    "Server address" : "Serverio adresas",
    "Port" : "Prievadas",
    "Log level" : "Žurnalo išsamumas",
    "More" : "Daugiau",
    "Less" : "Mažiau",
    "Version" : "Versija",
    "by" : " ",
    "Cheers!" : "Sveikinimai!",
    "Forum" : "Forumas",
    "Get the apps to sync your files" : "Atsisiųskite programėlių, kad sinchronizuotumėte savo failus",
    "Desktop client" : "Darbastalio klientas",
    "Android app" : "Android programa",
    "iOS app" : "iOS programa",
    "Show First Run Wizard again" : "Rodyti pirmo karto vedlį dar kartą",
    "You have used <strong>%s</strong> of the available <strong>%s</strong>" : "Jūs naudojate <strong>%s</strong> iš galimų <strong>%s</strong>",
    "Password" : "Slaptažodis",
    "Unable to change your password" : "Neįmanoma pakeisti slaptažodžio",
    "Current password" : "Dabartinis slaptažodis",
    "New password" : "Naujas slaptažodis",
    "Change password" : "Pakeisti slaptažodį",
    "Email" : "El. Paštas",
    "Your email address" : "Jūsų el. pašto adresas",
    "Profile picture" : "Profilio paveikslėlis",
    "Upload new" : "Įkelti naują",
    "Select new from Files" : "Pasirinkti naują iš failų",
    "Remove image" : "Pašalinti paveikslėlį",
    "Cancel" : "Atšaukti",
    "Choose as profile image" : "Pasirinkite profilio paveiksliuką",
    "Language" : "Kalba",
    "Help translate" : "Padėkite išversti",
    "Username" : "Prisijungimo vardas",
    "Create" : "Sukurti",
    "Admin Recovery Password" : "Administracinis atkūrimo slaptažodis",
    "Enter the recovery password in order to recover the users files during password change" : "Įveskite atkūrimo slaptažodį, kad atkurti naudotojo failus keičiant slaptažodį",
    "Group" : "Grupė",
    "Default Quota" : "Numatytoji kvota",
    "Unlimited" : "Neribota",
    "Other" : "Kita",
    "Full Name" : "Pilnas vardas",
    "Quota" : "Limitas",
    "change full name" : "keisti pilną vardą",
    "set new password" : "nustatyti naują slaptažodį",
    "Default" : "Numatytasis"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> owncloud-9.1.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/settings/l10n/lt_LT.js <==
OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Neteisingas slaptažodis",
    "No user supplied" : "Nepateiktas naudotojas",
    "Authentication error" : "Autentikacijos klaida",
    "Please provide an admin recovery password, otherwise all user data will be lost" : "Prašome įvesti administratoriaus atkūrimo slaptažodį, kitaip visi naudotojo suomenys bus prarasti",
    "Wrong admin recovery password. Please check the password and try again." : "Netinkamas administratoriau atkūrimo slaptažodis. Prašome pasitikrinti ir bandyti vėl.",
    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Vartotojo slaptažodžio pakeitimas negalimas, bet šifravimo raktas atnaujintas sėkmingai.",
    "Unable to change password" : "Nepavyksta pakeisti slaptažodžio",
    "Enabled" : "Įjungta",
    "Not enabled" : "Neįjungta",
    "Federated Cloud Sharing" : "Viešas dalijimasis padebesiu",
    "Saved" : "Išsaugoti",
    "Email sent" : "Laiškas išsiųstas",
    "Invalid mail address" : "Neteisingas pašto adresas",
    "Your %s account was created" : "Tavo paskyra %s sukurta",
    "Unable to delete user." : "Nepavyko ištrinti vartotojo.",
    "Email saved" : "El. paštas išsaugotas",
    "Your full name has been changed." : "Pilnas vardas pakeistas.",
    "Unable to change full name" : "Nepavyko pakeisti pilno vardo",
    "APCu" : "APCu",
    "Redis" : "Redis",
    "Security & setup warnings" : "Saugos ir diegimo perspėjimai",
    "Sharing" : "Dalijimasis",
    "Server-side encryption" : "Šifravimas serveryje",
    "External Storage" : "Išorinės saugyklos",
    "Cron" : "Cron",
    "Email server" : "Pašto serveris",
    "Log" : "Žurnalas",
    "Tips & tricks" : "Patarimai ir gudrybės",
    "Updates" : "Atnaujinimai",
    "Couldn't remove app." : "Nepavyko pašalinti programėlės.",
    "Language changed" : "Kalba pakeista",
    "Invalid request" : "Klaidinga užklausa",
    "Admins can't remove themself from the admin group" : "Administratoriai negali pašalinti savęs iš administratorių grupės",
    "Unable to add user to group %s" : "Nepavyko pridėti vartotojo prie grupės %s",
    "Unable to remove user from group %s" : "Nepavyko ištrinti vartotojo iš grupės %s",
    "Couldn't update app." : "Nepavyko atnaujinti programos.",
    "All" : "Viskas",
    "Please wait...." : "Prašome palaukti...",
    "Error while disabling app" : "Klaida išjungiant programą",
    "Disable" : "Išjungti",
    "Enable" : "Įjungti",
    "Error while enabling app" : "Klaida įjungiant programą",
    "Updating...." : "Atnaujinama...",
    "Error while updating app" : "Įvyko klaida atnaujinant programą",
    "Updated" : "Atnaujinta",
    "Delete" : "Ištrinti",
    "Select a profile picture" : "Pažymėkite profilio paveikslėlį",
    "Very weak password" : "Labai silpnas slaptažodis",
    "Weak password" : "Silpnas slaptažodis",
    "So-so password" : "Neblogas slaptažodis",
    "Good password" : "Geras slaptažodis",
    "Strong password" : "Stiprus slaptažodis",
    "Groups" : "Grupės",
    "undo" : "anuliuoti",
    "never" : "niekada",
    "add group" : "pridėti grupę",
    "A valid username must be provided" : "Vartotojo vardas turi būti tinkamas",
    "A valid password must be provided" : "Slaptažodis turi būti tinkamas",
    "__language_name__" : "Lietuvių",
    "Unlimited" : "Neribota",
    "Fatal issues only" : "Tik kritinės problemos",
    "None" : "Nieko",
    "Login" : "Prisijungti",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "Trūksta PHP modulio „fileinfo“. Labai rekomenduojame įjungti šį modulį, kad gauti geriausius rezultatus nustatant mime-tipą.",
    "Open documentation" : "Atidaryti dokumentą",
    "Allow apps to use the Share API" : "Leidžia programoms naudoti Share API",
    "Allow public uploads" : "Leisti viešus įkėlimus",
    "days" : "dienos",
    "Allow resharing" : "Leisti dalintis",
    "Execute one task with each page loaded" : "Įvykdyti vieną užduotį su kiekvieno puslapio įkėlimu",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php yra registruotas tinklapio suplanuotų užduočių paslaugose, kad iškviesti cron.php kas 15 minučių per http.",
    "Encryption" : "Šifravimas",
    "Authentication required" : "Reikalinga autentikacija",
    "Server address" : "Serverio adresas",
    "Port" : "Prievadas",
    "More" : "Daugiau",
    "Less" : "Mažiau",
    "Version" : "Versija",
    "Cheers!" : "Sveikinimai!",
    "Forum" : "Forumas",
    "Profile picture" : "Profilio paveikslėlis",
    "Upload new" : "Įkelti naują",
    "Remove image" : "Pašalinti paveikslėlį",
    "Cancel" : "Atšaukti",
    "Email" : "El. Paštas",
    "Your email address" : "Jūsų el. pašto adresas",
    "Password" : "Slaptažodis",
    "Unable to change your password" : "Neįmanoma pakeisti slaptažodžio",
    "Current password" : "Dabartinis slaptažodis",
    "New password" : "Naujas slaptažodis",
    "Change password" : "Pakeisti slaptažodį",
    "Language" : "Kalba",
    "Help translate" : "Padėkite išversti",
    "Name" : "Pavadinimas",
    "Username" : "Prisijungimo vardas",
    "Get the apps to sync your files" : "Atsisiųskite programėlių, kad sinchronizuotumėte savo failus",
    "Desktop client" : "Darbastalio klientas",
    "Android app" : "Android programa",
    "iOS app" : "iOS programa",
    "Show First Run Wizard again" : "Rodyti pirmo karto vedlį dar kartą",
    "Create" : "Sukurti",
    "Admin Recovery Password" : "Administracinis atkūrimo slaptažodis",
    "Enter the recovery password in order to recover the users files during password change" : "Įveskite atkūrimo slaptažodį, kad atkurti naudotojo failus keičiant slaptažodį",
    "Group" : "Grupė",
    "Default Quota" : "Numatytoji kvota",
    "Other" : "Kita",
    "Full Name" : "Pilnas vardas",
    "Quota" : "Limitas",
    "change full name" : "keisti pilną vardą",
    "set new password" : "nustatyti naują slaptažodį",
    "Default" : "Numatytasis"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && (n%100<10 || n%100>=20) ? 1 : 2);");
